'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _emojibaseRegex = require('emojibase-regex');

var _emojibaseRegex2 = _interopRequireDefault(_emojibaseRegex);

var _emoticon = require('emojibase-regex/emoticon');

var _emoticon2 = _interopRequireDefault(_emoticon);

var _shortcode = require('emojibase-regex/shortcode');

var _shortcode2 = _interopRequireDefault(_shortcode);

var _Matcher2 = require('../Matcher');

var _Matcher3 = _interopRequireDefault(_Matcher2);

var _Emoji = require('../components/Emoji');

var _Emoji2 = _interopRequireDefault(_Emoji);

var _EmojiData = require('../data/EmojiData');

var _EmojiData2 = _interopRequireDefault(_EmojiData);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var EMOTICON_BOUNDARY_REGEX = new RegExp('(^|\\\b|\\s)(' + _emoticon2.default.source + ')(?=\\s|\\\b|$)'); /**
                                                                                                            * @copyright   2016, Miles Johnson
                                                                                                            * @license     https://opensource.org/licenses/MIT
                                                                                                            * 
                                                                                                            */

var EmojiMatcher = function (_Matcher) {
  (0, _inherits3.default)(EmojiMatcher, _Matcher);

  function EmojiMatcher(name) {
    var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var factory = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
    (0, _classCallCheck3.default)(this, EmojiMatcher);
    return (0, _possibleConstructorReturn3.default)(this, (EmojiMatcher.__proto__ || (0, _getPrototypeOf2.default)(EmojiMatcher)).call(this, name, (0, _extends3.default)({
      convertEmoticon: false,
      convertShortcode: false,
      convertUnicode: false,
      enlargeThreshold: 1,
      renderUnicode: false
    }, options), factory));
  }

  (0, _createClass3.default)(EmojiMatcher, [{
    key: 'replaceWith',
    value: function replaceWith(match) {
      var props = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      if (this.options.renderUnicode) {
        return props.unicode;
      }

      return _react2.default.createElement(_Emoji2.default, props);
    }
  }, {
    key: 'asTag',
    value: function asTag() {
      return 'img';
    }
  }, {
    key: 'match',
    value: function match(string) {
      var _this2 = this;

      var matchers = [];
      var response = null;

      if (this.options.convertEmoticon) {
        matchers.push(this.matchEmoticon);
      }

      if (this.options.convertShortcode) {
        matchers.push(this.matchShortcode);
      }

      if (this.options.convertUnicode) {
        matchers.push(this.matchUnicode);
      }

      matchers.some(function (matcher) {
        response = matcher.call(_this2, string);

        return !!response;
      });

      return response;
    }
  }, {
    key: 'matchEmoticon',
    value: function matchEmoticon(string) {
      var response = this.doMatch(string, EMOTICON_BOUNDARY_REGEX, function (matches) {
        return {
          emoticon: matches[0].trim()
        };
      });

      if (response && response.emoticon && this.data.EMOTICON_TO_UNICODE[response.emoticon]) {
        response.unicode = this.data.EMOTICON_TO_UNICODE[response.emoticon];
        response.match = response.emoticon;

        return response;
      }

      return null;
    }
  }, {
    key: 'matchShortcode',
    value: function matchShortcode(string) {
      var response = this.doMatch(string, _shortcode2.default, function (matches) {
        return {
          shortcode: matches[0].toLowerCase()
        };
      });

      if (response && response.shortcode && this.data.SHORTCODE_TO_UNICODE[response.shortcode]) {
        response.unicode = this.data.SHORTCODE_TO_UNICODE[response.shortcode];

        return response;
      }

      return null;
    }
  }, {
    key: 'matchUnicode',
    value: function matchUnicode(string) {
      var response = this.doMatch(string, _emojibaseRegex2.default, function (matches) {
        return {
          unicode: matches[0]
        };
      });

      if (response && response.unicode && this.data.EMOJIS[response.unicode]) {
        return response;
      }

      return null;
    }
  }, {
    key: 'onBeforeParse',
    value: function onBeforeParse(content, props, context) {
      if (context.emoji) {
        this.data = _EmojiData2.default.getInstance(context.emoji.locale);
      } else if ("production" !== process.env.NODE_ENV) {
        throw new Error('Missing emoji data. Have you loaded using `withEmojiData`?');
      }

      return content;
    }
  }, {
    key: 'onAfterParse',
    value: function onAfterParse(content, props) {
      if (content.length === 0) {
        return content;
      }

      var enlargeThreshold = this.options.enlargeThreshold;

      var valid = false;
      var count = 0;

      for (var i = 0, item = null; i < content.length; i += 1) {
        item = content[i];

        if (typeof item === 'string') {
          if (!item.match(/^\s+$/)) {
            valid = false;
            break;
          }
        } else if (_react2.default.isValidElement(item)) {
          if (item && item.type === _Emoji2.default) {
            count += 1;
            valid = true;

            if (count > enlargeThreshold) {
              valid = false;
              break;
            }
          } else {
            valid = false;
            break;
          }
        } else {
          valid = false;
          break;
        }
      }

      if (!valid) {
        return content;
      }

      return content.map(function (item) {
        if (!item || typeof item === 'string') {
          return item;
        }

        return _react2.default.cloneElement(item, (0, _extends3.default)({}, item.props, {
          enlargeEmoji: true
        }));
      });
    }
  }]);
  return EmojiMatcher;
}(_Matcher3.default);

exports.default = EmojiMatcher;